from enum import Enum
from typing import List

from commitizen.commands.check import Check
from commitizen.config.base_config import BaseConfig
from commitizen.exceptions import InvalidCommitMessageError, NoCommitsFoundError

from lupin_grognard.core.commit import Commit


class CheckMethod(Enum):
    MESSAGE = "message"
    REV_RANGE = "rev_range"


def get_hash_last_commit(commit_list) -> str:
    last_commit = commit_list[-1]
    commit = Commit(commit=last_commit)
    return commit.hash


def get_hash_first_commit(commit_list) -> str:
    last_commit = commit_list[0]
    commit = Commit(commit=last_commit)
    return commit.hash


def check_commit_with_commitizen(
    check_method: CheckMethod, commit_message=None, commits: List = None
) -> str | None:
    config = BaseConfig()
    args = {}
    if check_method == CheckMethod.MESSAGE:
        args = {check_method.value: f"{commit_message}"}
    elif check_method == CheckMethod.REV_RANGE:
        first_commit = get_hash_first_commit(commit_list=commits)
        last_commit = get_hash_last_commit(commit_list=commits)
        args = {check_method.value: f"{last_commit}..{first_commit}"}

    commitizen = Check(config=config, arguments=args)
    try:
        output = commitizen.__call__()
    except InvalidCommitMessageError as e:
        output = e.args[0]
    except NoCommitsFoundError as e:
        output = e.args[0]
    return output
