import re
from typing import List


def read_file(file: str) -> str:
    with open(f"{file}", "r") as file:
        data = file.read()
        return data


def write_file(file: str, content: str):
    with open(f"{file}", "w") as outfile:
        outfile.write(content)


def get_version():
    """get version from setup.cfg file and
    update __version__ in lupin_grognard.__init__.py
    """
    setup_cfg = read_file("setup.cfg")
    _version = re.search(
        r"(^version = )(\d{1,2}\.\d{1,2}\.\d{1,2})(\.[a-z]{1,})?(\d{1,2})?",
        setup_cfg,
        re.MULTILINE,
    )
    version = ""
    for group in _version.group(2, 3, 4):
        if group is not None:
            version = version + str(group)
    content = f'__version__ = "{version}"\n'
    write_file(file="lupin_grognard/__init__.py", content=content)
    return version


def create_branch_list(branches_name: str) -> List:
    comma = branches_name.find(",")
    if comma == -1:
        branch_list = branches_name.split()
    else:
        branches_name = branches_name.replace(",", " ")
        branch_list = branches_name.split()
    return branch_list
